define(function(require, exports, module) {
    var _ = require('underscore');
    var BaseChoiceView = require("./basechoiceview");
    var BaseDropdownViewMixin = require("./basedropdownviewmixin");
    var SplunkUtil = require('splunk.util');

    // See http://ricostacruz.com/backbone-patterns/#mixins for
    // this mixin pattern.
    var DropdownView = BaseChoiceView.extend(
        _.extend({}, BaseDropdownViewMixin, {
            moduleId: module.id,
            
            className: "splunk-dropdown splunk-choice-input",
            selectRoot: '<input type="hidden"/>',
            valueIsList: false,
            normalizeOptions: function(settings, options) {

                if (options.hasOwnProperty("managerid") && !settings.get("managerid")) {
                    settings.set("managerid", options["managerid"]);
                }

                if (options.hasOwnProperty("valueField") && !settings.get("valueField")) {
                    settings.set("valueField", options["valueField"]);
                }

                if (options.hasOwnProperty("labelField") && !settings.get("labelField")) {
                    settings.set("labelField", options["labelField"]);
                }

                if (options.hasOwnProperty("width") && !settings.get("width")) {
                    settings.set("width", options["width"]);
                }

                if (options.hasOwnProperty("minimumResultsForSearch") && !settings.get("minimumResultsForSearch")) {
                    settings.set("minimumResultsForSearch", options["minimumResultsForSearch"]);
                }

                if (options.hasOwnProperty("disabled") && !settings.get("disabled")) {
                    settings.set("disabled", SplunkUtil.normalizeBoolean(options["disabled"]) ? true : false);
                }

                if (options.hasOwnProperty("default") && !settings.get("default")) {
                    settings.set("default", options["default"]);
                }

                if (options.hasOwnProperty("data") && !settings.get("data")) {
                    settings.set("data", options["data"]);
                }

                if (options.hasOwnProperty("id") && !settings.get("id")) {
                    settings.set("id", options["id"]);
                }

                if (options.hasOwnProperty("name") && !settings.get("name")) {
                    settings.set("name", options["name"]);
                }
            },
            initialize: function() {
                this.options = _.extend({}, BaseChoiceView.prototype.options, this.options);
                BaseChoiceView.prototype.initialize.apply(this, arguments);
                this.normalizeOptions(this.settings, this.options);
                this.settings.on("change:width", _.debounce(this.render, 0), this);
            },
            remove: function() {
                BaseDropdownViewMixin.remove.apply(this, arguments);
                BaseChoiceView.prototype.remove.apply(this, arguments);
            }
        })
    );

    return DropdownView;
});
