define(
    [
        'jquery',
        'underscore',
        'backbone',
        'module',
        'views/managementconsole/table/controls/SimpleDialog',
        'uri/route'
    ],
    function(
        $,
        _,
        Backbone,
        module,
        SimpleDialog,
        route
    ) {
        var TEXT = {
            TITLE: _('Are you sure?').t(),
            WARNING: _('WARNING').t(),
            P1: _('Do not configure the DMC in distributed mode if this is a production search head. Doing so can change the behavior of all searches on this instance.  This is dangerous and unsupported.').t(),
            P2_1: _('If you want to configure the DMC in distributed mode, you must locate the DMC on an instance that is not a production search head.  For precise details on where to locate a distributed mode DMC, see ').t(),
            P2_2: _('Which instance should host the console?').t(),
            P3: _('Are you sure you want to continue?').t()
        };

        return SimpleDialog.extend({
            moduleId: module.id,

            initialize: function(options) {
                this.compiledMessageTemplate = _.template(this.messageTemplate);

                var defaults = {
                    title: TEXT.TITLE,
                    message: this.compiledMessageTemplate({
                        helpLink: route.docHelp(
                            this.model.application.get('root'),
                            this.model.application.get('locale'),
                            'app.management_console.managementconsole_configure'
                        )
                    })
                };
                this.options = _.extend({}, defaults, this.options);
                SimpleDialog.prototype.initialize.apply(this, arguments);
            },

            events: $.extend(
                SimpleDialog.prototype.events,
                {
                    'click .btn.no': function(e) {
                        this.trigger('proceed', false);
                    },
                    'click .btn.yes': function(e) {
                        this.trigger('proceed', true);
                    }
                }
            ),

            render: function() {
                this.$(SimpleDialog.FOOTER_SELECTOR).append(SimpleDialog.BUTTON_NO);
                this.$(SimpleDialog.FOOTER_SELECTOR).append(SimpleDialog.BUTTON_YES);
                return this;
            },

            // TODO you have to generate this url, not hardcode it
            messageTemplate: '' +
                '<p><strong>' + TEXT.WARNING + ':</strong> ' + TEXT.P1 + '</p>' +
                '<p>' + TEXT.P2_1 + '<a href="<%- helpLink %>" class="external" target="_blank">' + TEXT.P2_2 + '</a></p>' +
                '<p>' + TEXT.P3 + '</p>'
        });
    }
);