define(
    [
        'jquery',
        'underscore',
        'backbone',
        'views/shared/FlashMessages',
        'splunk.util'
    ], 
    function($, _, Backbone, FlashMessages, splunkUtil) {

        var FlashMessagesView = FlashMessages.extend({
            initialize: function(options) {
                FlashMessages.prototype.initialize.call(this, options);

                this.renderMessagesList = false;
            },
            events: $.extend({}, FlashMessages.prototype.events, {
                'click .error-details': function(e) {
                    e.preventDefault();
                    this.renderMessagesList = !this.renderMessagesList;
                    this.renderMessages();
                }
            }),
            renderMessages: function() {
                if (!this.model.searchJob.entry.content.get('isFailed') && this.flashMsgCollection.length > 1) {
                    var linkTemplate, error,
                    messagesCount =  this.flashMsgCollection.length;
                    
                    error = splunkUtil.sprintf("%s errors occurred while the search was executing. Therefore, search results might be incomplete. ", messagesCount);

                    linkTemplate = _.template(this.toggleLinkTemplate, { 
                        error: error,
                        expandedState: this.renderMessagesList
                    });

                    this.$el.html(linkTemplate);
                    
                    if (this.renderMessagesList) {
                        this.insertMessages(this.messagesListTemplate);
                    }
                } else {
                    this.insertMessages(FlashMessages.prototype.template);
                }
            },
            insertMessages: function(errorTemplate) {
                this.$el.append(_.template(errorTemplate, {
                    flashMessages: this.flashMsgCollection
                }));
            },
            render: function() {
                this.$el.empty();
                this.renderMessages();
                (!this.flashMsgCollection.length) ? this.$el.hide() : this.$el.show();
                return this;
            },
            messagesListTemplate: '\
                <ul>\
                    <% flashMessages.each(function(flashMessage){ %> \
                        <li><%= flashMessage.get("html") %></li> \
                    <% }); %> \
                </ul>\
            ',
            toggleLinkTemplate: '\
                <div class="alert alert-error">\
                    <i class="icon-alert"></i>\
                    <%= error %>\
                    <% if (expandedState) { %> \
                        <a class="error-details" href="#"><%- _("Hide errors.").t() %></a>\
                    <% } else { %> \
                        <a class="error-details" href="#"><%- _("Show errors.").t() %></a>\
                    <% } %> \
                </div>\
            '
        });

        return FlashMessagesView;
    }
);